<?php

namespace QodeTours\CPT\Tours\Shortcodes;

use QodeTours\Lib\ShortcodeInterface;

class TopReviewsCarousel implements ShortcodeInterface {
	private $base;
	
	public function __construct() {
		$this->base = 'qode_top_reviews_carousel';
		
		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
        $criteria_ratings = qode_rating_criteria_for_vc();
		
		vc_map(
			array(
				'name'                      => esc_html__( 'Top Reviews Carousel', 'qode-tours' ),
				'base'                      => $this->base,
                'category'        			=> esc_html__('by QODE TOURS', 'qode-tours'),
				'icon'                      => 'icon-wpb-top-reviews-carousel extended-custom-icon-qode',
				'allowed_container_element' => 'vc_row',
				'params'                    => array(
					array(
						'type'        => 'textfield',
						'param_name'  => 'title',
						'heading'     => esc_html__( 'Title', 'qode-tours' ),
						'admin_label' => true
					),
                    array(
                        'type'        => 'dropdown',
                        'param_name'  => 'title_tag',
                        'heading'     => esc_html__( 'Title Tag', 'qode-tours' ),
                        'value'       => array(
                            ''      =>  '',
                            'h1'    =>  'h1',
                            'h2'    =>  'h2',
                            'h3'    =>  'h3',
                            'h4'    =>  'h4',
                            'h5'    =>  'h5',
                            'h6'    =>  'h6'
                        )
                    ),
                    array(
                        'type'        => 'colorpicker',
                        'param_name'  => 'title_color',
                        'heading'     => esc_html__( 'Title Color', 'qode-tours' )
                    ),
					array(
						'type'        => 'textfield',
						'param_name'  => 'number_of_reviews',
						'heading'     => esc_html__( 'Number of Reviews', 'qode-tours' ),
						'description' => esc_html__( 'Leave empty for all', 'qode-tours' )
					),
                    array(
                        'type'        => 'dropdown',
                        'param_name'  => 'review_criteria',
                        'heading'     => esc_html__( 'Order by Review Criteria', 'qode-tours' ),
                        'value'       => $criteria_ratings,
                        'save_always' => true
                    ),
                    array(
                        'type'        => 'dropdown',
                        'param_name'  => 'enable_shadow',
                        'heading'     => esc_html__( 'Enable Shadow', 'qode-tours' ),
                        'description'   => esc_html__("Enable this option if you would like to show shadow around reviews' box", 'qode-tours'),
                        'value'       => array(
                            esc_html__('No', 'qode-tours')    =>  'no',
                            esc_html__('Yes', 'qode-tours')    =>  'yes'
                        ),
                        'save_always' => true
                    )
				)
			)
		);
	}
	
	public function render( $atts, $content = null ) {
		$args   = array(
			'title'             => '',
			'number_of_reviews' => '',
            'review_criteria'   => '',
            'title_tag'         => 'h3',
            'title_color'       => '',
            'enable_shadow'     => ''
		);
		$params = shortcode_atts( $args, $atts );
		
		$params['reviews']        = $this->getTopReviews( $params );
		$params['title_style']    = $this->getTitleStyle( $params );
		$params['this_shortcode'] = $this;
		
		return qode_tours_get_tour_module_template_part( 'top-reviews-carousel/templates/top-reviews-carousel', 'tours', 'shortcodes', '', $params );
	}
	
	public function getTopReviews( $params ) {
        $number = isset( $params['number_of_reviews'] ) ? $params['number_of_reviews'] : '';

        $args = array(
            'status' => 'approve',
            'number' => $number,
            'post_type'	=> 'tour-item'
        );

        if ( isset( $params['review_criteria'] ) && ! empty( $params['review_criteria'] ) ) {
            $meta_query = array();

            $meta_query[]       = array(
                'key'     => $params['review_criteria'],
                'compare' => 'EXISTS'
            );
            $args['meta_query'] = $meta_query;
            $args['orderby']    = 'meta_value';
        }

        $comments = get_comments( $args );

        return $comments;
	}
	
	public function generateItemParams( $params ) {
		$comment                     = $params['comment'];
		$new_comment                 = array();
		$new_comment['comment_id']   = $comment->comment_ID;
		$new_comment['post_link']    = get_the_permalink( $comment->comment_post_ID );
		$new_comment['post_title']   = get_the_title( $comment->comment_post_ID );
		$new_comment['comment_text'] = get_comment_text( $comment->comment_ID );
		$new_comment['auhtor_email'] = $comment->comment_author_email;

        if ( isset( $params['review_criteria'] ) && ! empty( $params['review_criteria'] ) ) {
            $new_comment['review_value'] = get_comment_meta( $comment->comment_ID, $params['review_criteria'], true );
        }

		return $new_comment;
	}

	private function getTitleStyle( $params ){
        $styles = array();

        if(!empty($params['title_color'])) {
            $styles[] = 'color: '.$params['title_color'];
        }

        return $styles;
    }
}